@@ -32,7 +32,6 @@ from xklb.utils import (
     get_ordinal_media,
     log,
     mv_to_keep_folder,
-    print_query,
     remove_media,
     stop,
 )
@@ -44,11 +43,10 @@ def override_sort(string):
     YEAR_MONTH = lambda var: f"cast(strftime('%Y%m',datetime({var} / 1000000000, 'unixepoch')) as int)"
 
     return (
-        string.replace("created", YEAR_MONTH("time_created"))
-        .replace("modified", YEAR_MONTH("time_modified"))
+        string.replace("month_created", YEAR_MONTH("time_created"))
+        .replace("month_modified", YEAR_MONTH("time_modified"))
         .replace("random", "random()")
         .replace("priority", "play_count, round(duration / size,7)")
-        .replace("sub", "subtitle_count > 0")
     )
 
 
@@ -189,8 +187,6 @@ Double spaces means one space
     parser.add_argument("--post-action", "--action", "-k", default="keep", help="Choose what to do after playing")
     parser.add_argument("--shallow-organize", default="/mnt/d/")
 
-    parser.add_argument("--move", "-mv", help="lt -l 1 -mv dest/folder/; move a file into dest/folder/")
-
     parser.add_argument("--ignore-errors", "--ignoreerrors", action="store_true")
     parser.add_argument("--verbose", "-v", action="count", default=0)
     args = parser.parse_args()
@@ -387,10 +383,15 @@ def play(args, media: pd.DataFrame):
     for m in media.to_records(index=False):
         media_file = m["path"]
 
-        if (
-            args.play_in_order > 1
-            or (args.action == Subcommand.listen and "audiobook" in media_file.lower())
-            or (args.action == Subcommand.tubelisten and m["title"] and "audiobook" in m["title"].lower())
+        if any(
+            [
+                args.play_in_order > 1 and args.action not in [Subcommand.listen, Subcommand.tubelisten],
+                args.play_in_order >= 1 and args.action == Subcommand.listen and "audiobook" in media_file.lower(),
+                args.play_in_order >= 1
+                and args.action == Subcommand.tubelisten
+                and m["title"]
+                and "audiobook" in m["title"].lower(),
+            ]
         ):
             media_file = get_ordinal_media(args, media_file)
 
@@ -584,18 +585,6 @@ def printer(args, query, bindings):
     stop()
 
 
-def mover(args, media):
-    Path(args.move).mkdir(exist_ok=True, parents=True)
-    keep_path = str(Path(args.move).resolve())
-
-    for media in media[["path"]]:
-        if Path(media).exists() and "/keep/" not in media:
-            shutil.move(media, keep_path)
-
-        remove_media(args, media, quiet=True)
-    stop()
-
-
 def process_actions(args):
     args.con = sqlite_con(args.db)
     query, bindings = construct_query(args)
@@ -608,9 +597,6 @@ def process_actions(args):
         print("No media found")
         stop()
 
-    if args.move:
-        mover(args, media)
-
     play(args, media)
 
 
