@@ -2,8 +2,10 @@ import argparse
 import math
 import os
 import shutil
+import sys
 import tempfile
 import textwrap
+from copy import deepcopy
 from datetime import datetime, timedelta
 from pathlib import Path
 from sqlite3 import OperationalError
@@ -29,29 +31,20 @@ from xklb.utils import (
 )
 
 
-def create_download_archive(args):
-    user_download_archive = args.yt_dlp_config.pop("download_archive", None)
-    download_archive_temp = tempfile.mktemp()
-
-    query = "select distinct ie_key, id from media"
-    media = pd.DataFrame([dict(r) for r in args.con.execute(query).fetchall()])
-
-    ax_txt = media.apply(lambda m: f"{m['ie_key'].lower()} {m['id']}", axis=1).to_string(index=False, header=False)
-    Path(download_archive_temp).write_text(ax_txt)
-
-    if user_download_archive:
-        with open(download_archive_temp, "ab") as wfd:
-            for f in [user_download_archive]:
-                with open(f, "rb") as fd:
-                    shutil.copyfileobj(fd, wfd)
-                    wfd.write(b"\n")
-
-    return download_archive_temp
-
-
 def parse_args(action):
     parser = argparse.ArgumentParser()
     parser.add_argument("db", nargs="?", default="tube.db")
+    if action == "add":
+        parser.add_argument("playlists", nargs="+")
+        parser.add_argument("-f", "--overwrite-db", action="store_true", help="Delete db file before scanning")
+        parser.add_argument(
+            "--lightweight",
+            "-lw",
+            action="store_true",
+            help="lightweight add playlist: Use with --yt-dlp-config download-archive=archive.txt to inform tubeadd",
+        )
+    elif action == "update":
+        parser.add_argument("playlists", nargs="*")
 
     parser.add_argument(
         "--yt-dlp-config",
@@ -63,23 +56,13 @@ def parse_args(action):
         help="Add key/value pairs to override or extend default yt-dlp configuration",
     )
     parser.add_argument("-safe", "--safe", action="store_true", help="Skip generic URLs")
-    if action == "add":
-        parser.add_argument("playlists", nargs="+")
-        parser.add_argument("-f", "--overwrite-db", action="store_true", help="Delete db file before scanning")
-        parser.add_argument(
-            "--lightweight",
-            "-lw",
-            action="store_true",
-            help="lightweight add playlist: Use with --yt-dlp-config download-archive=archive.txt to inform tubeadd",
-        )
-    if action == "update":
-        parser.add_argument("playlists", nargs="*")
 
     parser.add_argument("-v", "--verbose", action="count", default=0)
     args = parser.parse_args()
+    args.action = action
     log.info(filter_None(args.__dict__))
 
-    if action == "add":
+    if args.action == "add":
         if args.overwrite_db:
             Path(args.db).unlink(missing_ok=True)
         Path(args.db).touch()
@@ -88,15 +71,6 @@ def parse_args(action):
     ydl_opts = {**default_ydl_opts, **args.yt_dlp_config}
     log.info(filter_None(ydl_opts))
 
-    if action == "update" or args.lightweight:
-        download_archive_temp = create_download_archive(args)
-        ydl_opts = {
-            **ydl_opts,
-            "download_archive": download_archive_temp,
-            "break_on_existing": True,
-            "break_per_url": True,
-        }
-
     args.ydl_opts = ydl_opts
     return args
 
@@ -109,7 +83,7 @@ def supported(url):  # thank you @dbr
     return False
 
 
-def consolidate(pl, v):
+def consolidate(playlist_path, v):
     ignore_keys = [
         "thumbnail",
         "thumbnails",
@@ -146,6 +120,39 @@ def consolidate(pl, v):
         "abr",
         "asr",
         "epoch",
+        "license",
+        "timestamp",
+        "track",
+        "subtitles",
+        "comments",
+        "author",
+        "text",
+        "parent",
+        "root",
+        "filesize",
+        "source_preference",
+        "video_ext",
+        "audio_ext",
+        "http_headers",
+        "User-Agent",
+        "Accept",
+        "Accept-Language",
+        "Sec-Fetch-Mode",
+        "navigate",
+        "Cookie",
+        "playlist_count",
+        "n_entries",
+        "playlist_autonumber",
+        "availability",
+        "formats",
+        "requested_formats",
+        "requested_entries",
+        "thumbnails",
+        "playlist_count",
+        'playlist_id',
+        'playlist_title',
+        'playlist_uploader',
+        'playlist_uploader_id',
     ]
 
     if v.get("title") in ["[Deleted video]", "[Private video]"]:
@@ -160,39 +167,33 @@ def consolidate(pl, v):
         upload_date = int(datetime.strptime(upload_date, "%Y%m%d").timestamp())
 
     cv = dict()
-    cv["path"] = safe_unpack(
-        v.pop("url", None),
-        v.pop("webpage_url", None),
-        v.pop("original_url", None),
-        pl.get("webpage_url"),
-        pl.get("original_url"),
-    )
+    cv["path"] = safe_unpack(v.pop("webpage_url", None), v.pop("url", None), v.pop("original_url", None))
     cv["size"] = v.pop("filesize_approx", None)
     cv["time_created"] = upload_date
-    cv["duration"] = v.pop("duration", None)
+    duration = v.pop("duration", None)
+    cv["duration"] = 0 if not duration else int(duration)
     cv["play_count"] = 0
     cv["language"] = v.pop("language", None)
     cv["tags"] = combine(v.pop("description", None), v.pop("categories", None), v.pop("tags", None))
     cv["id"] = v.pop("id")
     cv["ie_key"] = safe_unpack(v.pop("ie_key", None), v.pop("extractor_key", None), v.pop("extractor", None))
-    cv["title"] = safe_unpack(v.pop("title", None), pl.get("title"))
+    cv["title"] = safe_unpack(v.pop("title", None), v.get("playlist_title"))
     cv["view_count"] = v.pop("view_count", None)
     cv["width"] = v.pop("width", None)
     cv["height"] = v.pop("height", None)
-    cv["fps"] = v.pop("fps", None)
+    fps = v.pop("fps", None)
+    cv["fps"] = 0 if not fps else int(fps)
     cv["average_rating"] = v.pop("average_rating", None)
     cv["live_status"] = v.pop("live_status", None)
     cv["age_limit"] = v.pop("age_limit", None)
-    cv["playlist_path"] = safe_unpack(pl.get("webpage_url"), pl.get("original_url"))
-    cv["uploader_url"] = safe_unpack(
+    cv["playlist_path"] = playlist_path
+    cv["uploader"] = safe_unpack(
         v.pop("uploader_url", None),
         v.pop("channel_url", None),
         v.pop("uploader", None),
         v.pop("channel", None),
         v.pop("uploader_id", None),
         v.pop("channel_id", None),
-        pl.get("uploader", None),
-        pl.get("channel", None),
     )
 
     if v != {}:
@@ -202,44 +203,97 @@ def consolidate(pl, v):
     return cv
 
 
-def fetch_playlist(args, playlist) -> Tuple[(None | Dict), (None | List[Dict])]:
-    with yt_dlp.YoutubeDL(args.ydl_opts) as ydl:
-        pl = ydl.extract_info(playlist, download=False)
+def playlist_known(args, playlist_path):
+    try:
+        known = args.con.execute("select 1 from playlists where path=?", [playlist_path]).fetchone()
+    except Exception:
+        return False
+    if known is None:
+        return False
+    return known[0]
 
-        if not pl:
-            return None, None
 
-        pl.pop("availability", None)
-        pl.pop("formats", None)
-        pl.pop("requested_formats", None)
-        pl.pop("requested_entries", None)
-        pl.pop("thumbnails", None)
-        pl.pop("playlist_count", None)
+def video_known(args, playlist_path, path):
+    try:
+        known = args.con.execute(
+            "select 1 from media where playlist_path=? and path=?", [playlist_path, path]
+        ).fetchone()
+    except Exception:
+        return False
+    if known is None:
+        return False
+    return known[0]
 
-        entries = pl.pop("entries", None)
-        if entries is None:
-            entry = consolidate(pl, pl)
 
-            if not entry:
-                log.warning("No video found %s", pl)
-                return None, None
-
-            log.warning("Importing playlist-less media %s", entry)
-            return None, [entry]
-
-        entries = list(filter(None, [consolidate(pl, v) for v in entries if v]))
-        log.warning(f"Downloaded {len(entries)} entries from playlist '{pl['title']}'")
-
-        pl = consolidate(pl, pl)
-        pl = dict(
-            path=pl["path"],
-            id=pl["id"],
-            ie_key=pl["ie_key"],
-            title=pl["title"],
-            uploader_url=pl["uploader_url"],
+def save_entries(args, entries):
+    if entries:
+        entriesDF = pd.DataFrame(entries)
+        entriesDF.apply(pd.to_numeric, errors="ignore").convert_dtypes().to_sql(  # type: ignore
+            "media",
+            con=args.con,
+            if_exists="append",
+            index=False,
+            chunksize=70,
+            method="multi",
         )
 
-        return pl, entries
+
+def log_problem(args, playlist_path):
+    if args.action == "add":
+        log.warning("Could not add playlist %s", playlist_path)
+    else:
+        log.warning("Start of known playlist reached %s", playlist_path)
+
+
+def process_playlist(args, playlist_path) -> (List[Dict] | None):
+    class ExistingPlaylistVideoReached(yt_dlp.DownloadCancelled):
+        pass
+
+    class AddToArchivePP(yt_dlp.postprocessor.PostProcessor):
+        current_video_count = 0
+
+        def run(self, info):
+            entry = self._add_media(deepcopy(info))
+            self._add_playlist(deepcopy(info), entry)
+
+            self.current_video_count += 1
+            sys.stdout.write("\033[K\r")
+            print(f"{playlist_path}: added {self.current_video_count} videos", end="\r", flush=True)
+            return [], info
+
+        def _add_media(self, entry):
+            entry = consolidate(playlist_path, entry)
+            if video_known(args, playlist_path, entry["path"]):
+                raise ExistingPlaylistVideoReached
+            save_entries(args, [entry])
+            return entry
+
+        def _add_playlist(self, pl, entry):
+            pl = dict(
+                ie_key=safe_unpack(pl.get("ie_key"), pl.get("extractor_key"), pl.get("extractor")),
+                title=pl.get("playlist_title"),
+                path=playlist_path,
+                uploader=safe_unpack(pl.get("playlist_uploader_id"), pl.get("playlist_uploader")),
+                id=pl.get("playlist_id"),
+            )
+            if entry["path"] == pl["path"] or not pl.get('id'):
+                log.warning("Importing playlist-less media %s", pl["path"])
+            elif playlist_known(args, playlist_path):
+                pass
+            else:
+                plDF = pd.DataFrame([pl])
+                plDF.convert_dtypes().to_sql("playlists", con=args.con, if_exists="append", index=False)
+
+    with yt_dlp.YoutubeDL(args.ydl_opts) as ydl:
+        ydl.add_post_processor(AddToArchivePP(), when="pre_process")
+
+        try:
+            pl = ydl.extract_info(playlist_path, download=False, process=True)
+        except ExistingPlaylistVideoReached:
+            log_problem(args, playlist_path)
+        else:
+            if not pl:
+                log_problem(args, playlist_path)
 
 
 def get_playlists(args):
@@ -250,50 +304,39 @@ def get_playlists(args):
     return known_playlists
 
 
-def save_new_playlist(args, pl):
-    plDF = pd.DataFrame([pl])
-    plDF.apply(pd.to_numeric, errors="ignore").convert_dtypes().to_sql(  # type: ignore
-        "playlists",
-        con=args.con,
-        if_exists="append",
-        index=False,
-    )
-
-
-def save_entries(args, entries):
-    entriesDF = pd.DataFrame(entries)
-    entriesDF.apply(pd.to_numeric, errors="ignore").convert_dtypes().to_sql(  # type: ignore
-        "media",
-        con=args.con,
-        if_exists="append",
-        index=False,
-        chunksize=70,
-        method="multi",
-    )
-
-
 def tube_add():
     args = parse_args("add")
     known_playlists = get_playlists(args)
 
     for playlist in args.playlists:
-        if args.safe and not supported(playlist):
+        if playlist in known_playlists:
+            log.warning("Skipping known playlist: %s", playlist)
             continue
 
-        if playlist in known_playlists:
+        if args.safe and not supported(playlist):
+            log.warning("[safe_mode] unsupported playlist: %s", playlist)
             continue
 
         start = timer()
-        pl, entries = fetch_playlist(args, playlist)
+        process_playlist(args, playlist)
         end = timer()
-        log.info(f"{end - start:.1f} seconds to fetch playlist")
-        if not entries:
-            log.warning("Could not process %s", playlist)
+        log.info(f"{end - start:.1f} seconds to add new playlist and fetch videos")
+
+
+def tube_update():
+    args = parse_args("update")
+    known_playlists = get_playlists(args)
+
+    for playlist in args.playlists or get_playlists(args):
+
+        if playlist not in known_playlists:
+            log.warning("Skipping unknown playlist: %s", playlist)
             continue
 
-        if pl:
-            save_new_playlist(args, pl)
-        save_entries(args, entries)
+        start = timer()
+        process_playlist(args, playlist)
+        end = timer()
+        log.info(f"{end - start:.1f} seconds to update playlist")
 
 
 def human_time(hours):
@@ -364,13 +407,15 @@ def tube_list():
         nargs="*",
         default="p",
         choices=["p", "f", "a"],
-        help="""tubelist a -- means print an aggregate report
-tubelist f -- means print only filenames -- useful for piping to other utilities like xargs or GNU Parallel""",
+        help="""tubelist -p a -- means print playlists in a table
+tubelist -p a -- means print an aggregate report
+tubelist -p f -- means print only playlist urls -- useful for piping to other utilities like xargs or GNU Parallel""",
     )
     parser.add_argument(
         "--delete",
         "--remove",
         "--erase",
+        "--rm",
         "-rm",
         "-d",
         nargs="+",
@@ -387,20 +432,3 @@ tubelist f -- means print only filenames -- useful for piping to other utilities
         stop()
 
     printer(args)
-
-
-def tube_update():
-    args = parse_args("update")
-
-    for playlist in args.playlists or get_playlists(args):
-        start = timer()
-        _pl, entries = fetch_playlist(args, playlist)
-        end = timer()
-        log.info(f"{end - start:.1f} seconds to update playlist")
-        if not entries:
-            log.warning("Could not update %s", playlist)
-            continue
-
-        save_entries(args, entries)
-
-    Path(args.ydl_opts["download_archive"]).unlink()
