@@ -88,7 +88,7 @@ def argparse_log():
     logging.basicConfig(
         level=log_levels[min(len(log_levels) - 1, args.verbose)],
         format="%(message)s",
-        handlers=[RichHandler(show_time=False, show_level=False)],
+        handlers=[RichHandler(show_time=False, show_level=False, show_path=False)],
     )
     return logging.getLogger()
 
@@ -361,7 +361,7 @@ def safe_unpack(*list_, idx=0):
 class argparse_dict(argparse.Action):
     def __call__(self, parser, args, values, option_string=None):
         try:
-            d = dict(map(lambda x: x.split("="), values.split(" ")))
+            d = dict(map(lambda x: x.split("="), flatten([v.split(" ") for v in values])))
         except ValueError as ex:
             raise argparse.ArgumentError(self, f'Could not parse argument "{values}" as k1=1 k2=2 format')
         setattr(args, self.dest, d)
